#
# spec file for package xfce4-eyes-plugin
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define xfce_version 4.16.0
%define plugin eyes
Name:           xfce4-%{plugin}-plugin
Version:        4.7.0
Release:        1.1
Summary:        Eyes Plugin for the Xfce Panel
License:        GPL-2.0-or-later
Group:          System/GUI/XFCE
URL:            https://docs.xfce.org/panel-plugins/xfce4-eyes-plugin
Source0:        https://archive.xfce.org/src/panel-plugins/%{name}/4.7/%{name}-%{version}.tar.xz
BuildRequires:  fdupes
BuildRequires:  gettext >= 0.19.8
BuildRequires:  meson >= 0.54.0
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(glib-2.0) >= 2.50.0
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.22.0
BuildRequires:  pkgconfig(libxfce4panel-2.0) >= %{xfce_version}
BuildRequires:  pkgconfig(libxfce4ui-2) >= %{xfce_version}
BuildRequires:  pkgconfig(libxfce4util-1.0) >= %{xfce_version}
Requires:       xfce4-panel >= %{xfce_version}
Recommends:     %{name}-lang = %{version}
# package was renamed in 2019 after Leap 15.1
Provides:       xfce4-panel-plugin-%{plugin} = %{version}-%{release}
Obsoletes:      xfce4-panel-plugin-%{plugin} < %{version}-%{release}
Obsoletes:      xfce4-panel-plugin-%{plugin}-debuginfo

%description
The Eyes plugin adds moving eyes to the panel which watch your activities.

%package lang
Summary:        Translations for package %{name}
Group:          System/Localization
Requires:       %{name} = %{version}
Supplements:    %{name}
Provides:       %{name}-lang-all = %{version}
# package was renamed in 2019 after Leap 15.1
Obsoletes:      xfce4-panel-plugin-%{plugin}-lang < %{version}-%{release}
Provides:       xfce4-panel-plugin-%{plugin}-lang = %{version}-%{release}
BuildArch:      noarch

%description lang
Provides translations for the "%{name}" package.

%prep
%autosetup

%build
%meson
%meson_build

%install
%meson_install

rm -f %{buildroot}%{_libdir}/xfce4/panel/plugins/libeyes.la

%find_lang %{name} %{name}.lang %{?no_lang_C}

%fdupes %{buildroot}%{_datadir}

%files
%doc AUTHORS NEWS
%license COPYING
%{_libdir}/xfce4/panel/plugins/libeyes.so
%{_datadir}/icons/hicolor/*/apps/xfce4-eyes.*
%dir %{_datadir}/xfce4/eyes
%{_datadir}/xfce4/eyes/*
%{_datadir}/xfce4/panel/plugins/eyes.desktop

%files lang -f %{name}.lang

%changelog
* Thu May 29 2025 Maurizio Galli <maurizio.galli@suse.com>
- Update to version 4.7.0
  - Update README after switchover to meson
  - autotools-build: Explicitly require libxfce4util
  - build: Automate copyright year management
  - meson-build: Use shared_module()
  - Add about dialog
  - Add meson build
  - themes: Unify capitalization in file names
  - Translation Updates
* Sun Dec 29 2024 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 4.6.2
  * scan-build: Add false postive file
  * Revert "scan-build: Fix deadcode.DeadStores"
* Sun Dec 29 2024 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 4.6.1
  * Update copyright year
  * build: Bump dependency versions and fix deprecation warnings
  * scan-build: Fix deadcode.DeadStores
  * I18n: Update po/LINGUAS list
  * build: Use XDT_VERSION_INIT and get rid of configure.ac.in
  * build: Switch from intltool to gettext
  * build: Add GLib requirement
  * Fix make distcheck
  * Translation Updates
- Remove _service file
* Thu Apr  7 2022 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 4.6.0
  * Add Chibi theme (gxo#panel-plugins/xfce4-eyes-plugin!4)
  * Small code improvements
  * Translation Updates
* Wed Jun 24 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 4.5.1:
  * Update URLs. Remove ref. to translations.x.o (bxo#16162)
  * Allow compilation with panel 4.15
  * Replace GtkStock buttons
  * Improve spacing (bxo#14664)
  * Make build less verbose
  * AC_CONFIG_MACRO_DIR -> AC_CONFIG_MACRO_DIRS
  * Translation Updates
* Fri Aug 16 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Fixed sources in spec file
* Tue Jul 16 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Package renamed to follow upstream name xfce4-foo-plugin
- Use lang subpackage for manual edits instead of %%lang_package macro
- Cleaned up spec file
- Added bcond for git master builds
- Only add NEWS and omi Changelog
- Move COPYING under %%license macro
* Sun Nov 27 2016 seife+obs@b1-systems.com
- update to version 4.5.0:
  - port to gtk+3/libxfce4ui-2/libxfce4panel-2.0
  - translation updates
* Sun Mar 15 2015 gber@opensuse.org
- update to version 4.4.4
  - add ACLOCAL_AMFLAGS to Makefile.am
  - add .gitignore
  - fix IT_PROG_INTLTOOL warning
  - translation updates
* Tue Dec 23 2014 gber@opensuse.org
- update to version 4.4.3
  - fixes for the build system
  - translation updates
* Thu Mar  7 2013 gber@opensuse.org
- update to version 4.4.2
  - small optimizations to update function, making animation more
    smooth
  - support for deskbar mode and panel multi-row config
    (>=xfce4-panel-4.9.0)
  - make eye movement independent, like in xeyes
  - implement eye position calculations in 3D coordinates
  - build the plugin as a module
  - autotools update (automake-1.13 compatibility and other issues)
  - fix remembering theme
  - update size after panel orientation change
  - more translation updates
  - port to libxfce4ui
* Fri Apr 20 2012 gber@opensuse.org
- added documentation files
* Tue Apr 17 2012 gber@opensuse.org
- corrected source URL
* Tue Apr  3 2012 gber@opensuse.org
- specfile cleanup
- correct dependencies
- split off -lang subpackage
* Wed Mar  9 2011 gber@opensuse.org
- new package (split off from xfce4-panel-plugins)
